aboutsummaryrefslogtreecommitdiffstats
path: root/lib/compiler/src/compile.erl
diff options
context:
space:
mode:
authorTuncer Ayaz <[email protected]>2014-02-14 21:34:21 +0100
committerTuncer Ayaz <[email protected]>2014-02-14 21:47:20 +0100
commit6ce0f745f0048aa48222ba6bae220c3cb5a37959 (patch)
treeecb8b7cff485cb710e316329af863aeb1aa31dea /lib/compiler/src/compile.erl
parent9f2753f13c2a9b840e76fc10a12752aaa09a7e96 (diff)
downloadotp-6ce0f745f0048aa48222ba6bae220c3cb5a37959.tar.gz
otp-6ce0f745f0048aa48222ba6bae220c3cb5a37959.tar.bz2
otp-6ce0f745f0048aa48222ba6bae220c3cb5a37959.zip
compiler: update 'asm' deprecation message
Adapt 'asm' deprecation message to new version scheme.
Diffstat (limited to 'lib/compiler/src/compile.erl')
-rw-r--r--lib/compiler/src/compile.erl7
1 files changed, 3 insertions, 4 deletions
diff --git a/lib/compiler/src/compile.erl b/lib/compiler/src/compile.erl
index e79fe41f9b..b88f9792a5 100644
--- a/lib/compiler/src/compile.erl
+++ b/lib/compiler/src/compile.erl
@@ -430,10 +430,9 @@ pass(from_core) ->
pass(from_asm) ->
{".S",[?pass(beam_consult_asm)|asm_passes()]};
pass(asm) ->
- %% TODO: remove 'asm' in R18
- io:format("compile:file/2 option 'asm' has been deprecated and will be "
- "removed in R18.~n"
- "Use 'from_asm' instead.~n"),
+ %% TODO: remove 'asm' in 18.0
+ io:format("compile:file/2 option 'asm' has been deprecated and will be~n"
+ "removed in the 18.0 release. Use 'from_asm' instead.~n"),
pass(from_asm);
pass(from_beam) ->
{".beam",[?pass(read_beam_file)|binary_passes()]};